| Title: | Gordon Atlas for the 'ggseg' Ecosystem |
|---|---|
| Description: | Gordon resting-state cortical parcellation atlas for the 'ggseg' ecosystem. Provides a unified 'ggseg_atlas' object with 2D polygon geometry for use with 'ggseg'. |
| Authors: | Athanasia Mo Mowinckel [aut, cre] (ORCID: <https://orcid.org/0000-0002-5756-0223>) |
| Maintainer: | Athanasia Mo Mowinckel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 2.0.1 |
| Built: | 2026-05-23 09:18:00 UTC |
| Source: | https://github.com/ggsegverse/ggsegGordon |
Brain atlas for the Gordon cortical parcellation with 329 regions
based on resting-state functional connectivity boundaries.
Contains 2D polygon geometry for ggseg::geom_brain().
gordon()gordon()
A ggseg.formats::ggseg_atlas object (cortical).
Gordon EM, Laumann TO, Adeyemo B, Huckins JF, Kelley WM, Petersen SE (2016). Generation and Evaluation of a Cortical Area Parcellation from Resting-State Correlations. Cerebral Cortex, 26(1):288-303. doi:10.1093/cercor/bhu239
gordon() plot(gordon())gordon() plot(gordon())